@@ -34,6 +34,9 @@ class Config(object):
   IMPORT_MOVEMENTS_SNS_CLASS_NAME = 'com.cargochief.sdk.c4.sns.mcleod.ImportMovementsNotification'
   IMPORT_CARRIERS_SNS_SUBJECT = 'import-carriers'
   IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-carriers-test'
+  MINIMUM_MILES_PER_DAY = int(os.getenv('MINIMUM_MILES_PER_DAY', 300))
+  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-1.amazonaws.com/791608169866/booking-agent-worker-test'
+  BOOKING_ASSISTANT_DELAY_SECONDS=os.environ.get('BOOKING_ASSISTANT_DELAY_SECONDS', 0)
 
 class LocalConfig(Config):
   """Configurations for running and debugging locally, with a separate local database."""
@@ -54,6 +57,7 @@ class StagingConfig(Config):
   IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-movements-staging'
   PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-parsed-carrier-staging'
   IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-carriers-staging'
+  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-2.amazonaws.com/791608169866/booking-agent-worker-staging'
 
 class ProductionConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
@@ -62,6 +66,7 @@ class ProductionConfig(Config):
   BOOKING_ASSISTANT_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:booking-assistant-flow-prod'
   IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-movements-prod'
   IMPORT_CARRIERS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-1:791608169866:mcleod-import-carriers-prod'
+  BOOKING_ASSISTANT_FLOW_QUEUE='https://sqs.us-west-1.amazonaws.com/791608169866/awseb-e-3dhx3ncwcd-stack-AWSEBWorkerQueue-129YBH2WM1TD0'
 
 config_options = {
     'local': LocalConfig,
